from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.post_api_v1_experiments_id_set_flag_as_body import PostApiV1ExperimentsIdSetFlagAsBody
from ...models.post_api_v1_experiments_id_set_flag_as_response_200 import PostApiV1ExperimentsIdSetFlagAsResponse200
from ...models.post_api_v1_experiments_id_set_flag_as_response_401 import PostApiV1ExperimentsIdSetFlagAsResponse401
from ...types import Response


def _get_kwargs(
    id: int,
    *,
    body: PostApiV1ExperimentsIdSetFlagAsBody,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": f"/api/v1/experiments/{id}/set_flag_as",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]:
    if response.status_code == 200:
        response_200 = PostApiV1ExperimentsIdSetFlagAsResponse200.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = PostApiV1ExperimentsIdSetFlagAsResponse401.from_dict(response.json())

        return response_401
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    id: int,
    *,
    client: Union[AuthenticatedClient, Client],
    body: PostApiV1ExperimentsIdSetFlagAsBody,
) -> Response[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]:
    """Add flag to an experiment

    Args:
        id (int):
        body (PostApiV1ExperimentsIdSetFlagAsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]
    """

    kwargs = _get_kwargs(
        id=id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    id: int,
    *,
    client: Union[AuthenticatedClient, Client],
    body: PostApiV1ExperimentsIdSetFlagAsBody,
) -> Optional[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]:
    """Add flag to an experiment

    Args:
        id (int):
        body (PostApiV1ExperimentsIdSetFlagAsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]
    """

    return sync_detailed(
        id=id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    id: int,
    *,
    client: Union[AuthenticatedClient, Client],
    body: PostApiV1ExperimentsIdSetFlagAsBody,
) -> Response[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]:
    """Add flag to an experiment

    Args:
        id (int):
        body (PostApiV1ExperimentsIdSetFlagAsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]
    """

    kwargs = _get_kwargs(
        id=id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    id: int,
    *,
    client: Union[AuthenticatedClient, Client],
    body: PostApiV1ExperimentsIdSetFlagAsBody,
) -> Optional[Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]]:
    """Add flag to an experiment

    Args:
        id (int):
        body (PostApiV1ExperimentsIdSetFlagAsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[PostApiV1ExperimentsIdSetFlagAsResponse200, PostApiV1ExperimentsIdSetFlagAsResponse401]
    """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
            body=body,
        )
    ).parsed
